@@ -32,7 +32,7 @@ class Sms(webdriver.Remote):
             self.driver.send_sms('555-123-4567', 'Hey lol')
 
         Returns:
-            `WebDriver`
+            `appium.webdriver.webdriver.WebDriver`
         """
         self.execute(Command.SEND_SMS, {'phoneNumber': phone_number, 'message': message})
         return self
